@@ -1,9 +1,9 @@
 import time
 import pprint
 from manafa.services.batteryStatsService import BatteryStatsService
-from manafa.services.hunterService import HunterService
 from manafa.services.service import *
 from manafa.services.perfettoService import PerfettoService
+from manafa.services.hunterService import HunterService
 from manafa.perfetto.perfettoParser import PerfettoCPUfreqParser
 from manafa.batteryStats.BatteryStatsParser import BatteryStatsParser
 import argparse
@@ -57,8 +57,8 @@ class EManafa(Service):
 		pass
 
 	def init(self):
-		self.hunter.init()
 		self.boot_time = get_last_boot_time()
+		self.hunter.init(boot_time=self.boot_time)
 		self.batterystats.init(boot_time=self.boot_time)
 		self.perfetto.init(boot_time=self.boot_time)
 		self.__unplug_if_fully_charged()
@@ -67,31 +67,45 @@ class EManafa(Service):
 		self.batterystats.start()
 		self.perfetto.start()
 
-	def hunterStart(self):
-		filename = self.hunter.start()
-		return filename
-
-	def hunterParse(self,logfile):
-		self.hunter.parseFile(logfile)	
-
-	def hunterAddConsumption(self, function_name, position, consumption, per_component_consumption):
-		self.hunter.addConsumption(function_name,position,consumption,per_component_consumption)
-
-	def addConsumptionToTraceFile(self, filename):
-		self.hunter.addConsumptionToTraceFile(filename)	
-
 	def stop(self):
 		b_out = self.batterystats.stop()
 		p_out = self.perfetto.stop()
+		self.parseResults(b_out, p_out)
+  
+		if(len(self.bat_events.events) > 0):
+			hunter_out = self.hunter.start() #hunter start is to write to a log file (same as stop)
+			self.hunter.parseFile(hunter_out)	
+			hunter_trace = self.hunter.trace
+			
+			for i, function in enumerate(hunter_trace):
+				func_consumption = 0
+				for j, times in enumerate(hunter_trace[function]):
+					time = hunter_trace[function][j]
+					begin = time['begin_time']
+					end = time['end_time']
+					consumption, per_component_consumption = g.getConsumptionInBetween(begin, end)
+					self.hunter.addConsumption(function,j,consumption,per_component_consumption)
+					func_consumption += consumption
+				log("Total energy consumed by %s: %f Joules" % (function, func_consumption) , log_sev=LogSeverity.SUCCESS)
+
+			print("-----------------")
+			pprint.pprint(hunter_trace)
+			print("-----------------\nTIME_BAT_EVENTS")
+			begin = self.bat_events.events[0].time
+			print("BEGIN: " + str(begin))
+			end = g.bat_events.events[-1].time
+			print("END: " + str(end))
+
+			self.hunter.addConsumptionToTraceFile(hunter_out)
 		if self.unplugged:
 			self.__plug_back()
-		return b_out, p_out
+		return b_out, p_out, hunter_trace
 	
 	def clean(self):
 		self.batterystats.clean()
 		self.perfetto.clean()
 
-	def parseResults(self, bts_file="", pf_file=""):
+	def 	parseResults(self, bts_file="", pf_file=""):
 		if bts_file == "" or pf_file == "":
 			log("Empty result files", LogSeverity.FATAL)
 			raise Exception()
@@ -274,34 +288,8 @@ if __name__ == '__main__':
 		time.sleep(7) #do work
 		args.batstatsfile, args.perfettofile = g.stop()
 	g.parseResults(args.batstatsfile, args.perfettofile)
-  
-	if(len(g.bat_events.events) > 0):
-		hunter_file = g.hunterStart() #hunter start is to write to a log file (same as stop)
-		#hunter_file = "results/hunter/hunter.log"
-		g.hunterParse(hunter_file)
-		hunter_trace = g.hunter.trace
-		
-		for i, function in enumerate(hunter_trace):
-			func_consumption = 0
-			for j, times in enumerate(hunter_trace[function]):
-				time = hunter_trace[function][j]
-				begin = time['begin_time']
-				end = time['end_time']
-				consumption, per_component_consumption = g.getConsumptionInBetween(begin, end)
-				g.hunterAddConsumption(function,j,consumption,per_component_consumption)
-				func_consumption += consumption
-			log("Total energy consumed by %s: %f Joules" % (function, func_consumption) , log_sev=LogSeverity.SUCCESS)
-
-		print("-----------------")
-		pprint.pprint(hunter_trace)
-		print("-----------------\nTIME_BAT_EVENTS")
-		begin = g.bat_events.events[0].time
-		print("BEGIN: " + str(begin))
-		end = g.bat_events.events[-1].time
-		print("END: " + str(end))
-
-		g.addConsumptionToTraceFile(hunter_file)
-		#print("-----------------")
-		#pprint.pprint(hunter_trace)
-	else: 
-		log("Error with battery stats events", log_sev=LogSeverity.ERROR)
\ No newline at end of file
+	begin = g.bat_events.events[0].time  # first collected sample from batterystats
+	end = g.bat_events.events[-1].time  # last collected sample from batterystats
+	p,c = g.getConsumptionInBetween(begin,end)
+	print(p)
+	print(c)
\ No newline at end of file
