@@ -37,7 +37,7 @@ class PerfettoService(Service):
 	def export(self):
 		last_exported = ""
 		for f in os.listdir(self.results_dir):
-			execute_shell_command("%s/traceconv systrace %s/%s %s/%s.systrace" %(RESOURCES_DIR,self.results_dir,f,self.results_dir,f) )
+			res, o, e = execute_shell_command("chmod +x %s/traceconv ; %s/traceconv systrace %s/%s %s/%s.systrace" %(RESOURCES_DIR,RESOURCES_DIR,self.results_dir,f,self.results_dir,f) )
 			last_exported = "%s/%s.systrace" %(self.results_dir,f)
 		return last_exported
 
